summaryrefslogtreecommitdiffstats
path: root/akregator/src/feed.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/feed.cpp')
-rw-r--r--akregator/src/feed.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/akregator/src/feed.cpp b/akregator/src/feed.cpp
index f0574c31..edf1a790 100644
--- a/akregator/src/feed.cpp
+++ b/akregator/src/feed.cpp
@@ -87,7 +87,7 @@ class Feed::FeedPrivate
/** caches guids of tagged articles. key: tag, value: list of guids */
TQMap<TQString, TQStringList> taggedArticles;
/** list of deleted articles. This contains **/
TQValueList<Article> deletedArticles;
/** caches guids of deleted articles for notification */
@@ -402,7 +402,7 @@ void Feed::slotMarkAllArticlesAsRead()
TQValueList<Article>::Iterator en = tarticles.end();
for (it = tarticles.begin(); it != en; ++it)
- (*it).setStatus(Article::Read);
+ (*it).seStatus(Article::Read);
setNotificationMode(true, true);
}
}
@@ -412,7 +412,7 @@ void Feed::slotAddToFetchQueue(FetchQueue* queue, bool intervalFetchOnly)
queue->addFeed(this);
else
{
- uint now = TQDateTime::currentDateTime().toTime_t();
+ uint now = TQDateTime::tqcurrentDateTime().toTime_t();
// workaround for 3.5.x: if the last fetch went wrong, try again after 30 minutes
// this fixes annoying behaviour of akregator, especially when the host is reachable
@@ -450,7 +450,7 @@ void Feed::appendArticles(const RSS::Document &doc)
for (it = d_articles.begin(); it != en; ++it)
{
- if ( !d->articles.contains((*it).guid()) ) // article not in list
+ if ( !d->articles.tqcontains((*it).guid()) ) // article not in list
{
Article mya(*it, this);
mya.offsetPubDate(nudge);
@@ -464,9 +464,9 @@ void Feed::appendArticles(const RSS::Document &doc)
d->addedArticlesNotify.append(mya);
if (!mya.isDeleted() && !markImmediatelyAsRead())
- mya.setStatus(Article::New);
+ mya.seStatus(Article::New);
else
- mya.setStatus(Article::Read);
+ mya.seStatus(Article::Read);
changed = true;
}
@@ -479,12 +479,12 @@ void Feed::appendArticles(const RSS::Document &doc)
{
mya.setKeep(old.keep());
int oldstatus = old.status();
- old.setStatus(Article::Read);
+ old.seStatus(Article::Read);
d->articles.remove(old.guid());
appendArticle(mya);
- mya.setStatus(oldstatus);
+ mya.seStatus(oldstatus);
d->updatedArticlesNotify.append(mya);
changed = true;
@@ -519,7 +519,7 @@ bool Feed::usesExpiryByAge() const
bool Feed::isExpired(const Article& a) const
{
- TQDateTime now = TQDateTime::currentDateTime();
+ TQDateTime now = TQDateTime::tqcurrentDateTime();
int expiryAge = -1;
// check whether the feed uses the global default and the default is limitArticleAge
if ( d->archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge)
@@ -535,7 +535,7 @@ void Feed::appendArticle(const Article& a)
{
if ( (a.keep() && Settings::doNotExpireImportantArticles()) || ( !usesExpiryByAge() || !isExpired(a) ) ) // if not expired
{
- if (!d->articles.contains(a.guid()))
+ if (!d->articles.tqcontains(a.guid()))
{
d->articles[a.guid()] = a;
if (!a.isDeleted() && a.status() != Article::Read)
@@ -558,7 +558,7 @@ void Feed::fetch(bool followDiscovery)
{
if ((*it).status() == Article::New)
{
- (*it).setStatus(Article::Unread);
+ (*it).seStatus(Article::Unread);
}
}
@@ -618,7 +618,7 @@ void Feed::fetchCompleted(RSS::Loader *l, RSS::Document doc, RSS::Status status)
else
{
d->fetchError = true;
- d->lastErrorFetch = TQDateTime::currentDateTime().toTime_t();
+ d->lastErrorFetch = TQDateTime::tqcurrentDateTime().toTime_t();
emit fetchError(this);
}
return;
@@ -647,7 +647,7 @@ void Feed::fetchCompleted(RSS::Loader *l, RSS::Document doc, RSS::Status status)
appendArticles(doc);
- d->archive->setLastFetch( TQDateTime::currentDateTime().toTime_t());
+ d->archive->setLastFetch( TQDateTime::tqcurrentDateTime().toTime_t());
emit fetched(this);
}
@@ -726,10 +726,10 @@ void Feed::setUnread(int unread)
void Feed::setArticleDeleted(Article& a)
{
- if (!d->deletedArticles.contains(a))
+ if (!d->deletedArticles.tqcontains(a))
d->deletedArticles.append(a);
- if (!d->removedArticlesNotify.contains(a))
+ if (!d->removedArticlesNotify.tqcontains(a))
d->removedArticlesNotify.append(a);
articlesModified();
@@ -87,7 +87,7 @@ class Feed::FeedPrivate
/** caches guids of tagged articles. key: tag, value: list of guids */
TQMap<TQString, TQStringList> taggedArticles;
- /** list of deleted articles. This contains **/
+ /** list of deleted articles. This tqcontains **/
TQValueList<Article> deletedArticles;
/** caches guids of deleted articles for notification */